==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/DeploymentStacksParametersLinkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.DeploymentStacksParametersLinkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Entity representing the reference to the deployment parameters.
 * @property contentVersion If included, must match the ContentVersion in the template.
 * @property uri The URI of the parameters file.
 */
public data class DeploymentStacksParametersLinkArgs(
    public val contentVersion: Output<String>? = null,
    public val uri: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.resources.inputs.DeploymentStacksParametersLinkArgs> {
    override fun toJava(): com.pulumi.azurenative.resources.inputs.DeploymentStacksParametersLinkArgs =
        com.pulumi.azurenative.resources.inputs.DeploymentStacksParametersLinkArgs.builder()
            .contentVersion(contentVersion?.applyValue({ args0 -> args0 }))
            .uri(uri.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DeploymentStacksParametersLinkArgs].
 */
@PulumiTagMarker
public class DeploymentStacksParametersLinkArgsBuilder internal constructor() {
    private var contentVersion: Output<String>? = null

    private var uri: Output<String>? = null

    /**
     * @param value If included, must match the ContentVersion in the template.
     */
    @JvmName("dkcfmopvkqqfpjxd")
    public suspend fun contentVersion(`value`: Output<String>) {
        this.contentVersion = value
    }

    /**
     * @param value The URI of the parameters file.
     */
    @JvmName("jdvkuhxdyqcdqnyn")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value If included, must match the ContentVersion in the template.
     */
    @JvmName("oygwvtnqydxmwtay")
    public suspend fun contentVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentVersion = mapped
    }

    /**
     * @param value The URI of the parameters file.
     */
    @JvmName("uydoscmuxkekgbdq")
    public suspend fun uri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): DeploymentStacksParametersLinkArgs = DeploymentStacksParametersLinkArgs(
        contentVersion = contentVersion,
        uri = uri ?: throw PulumiNullFieldException("uri"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/DeploymentStacksParametersLinkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.DeploymentStacksParametersLinkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Entity representing the reference to the deployment parameters.
 * @property contentVersion If included, must match the ContentVersion in the template.
 * @property uri The URI of the parameters file.
 */
public data class DeploymentStacksParametersLinkArgs(
    public val contentVersion: Output<String>? = null,
    public val uri: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.resources.inputs.DeploymentStacksParametersLinkArgs> {
    override fun toJava(): com.pulumi.azurenative.resources.inputs.DeploymentStacksParametersLinkArgs =
        com.pulumi.azurenative.resources.inputs.DeploymentStacksParametersLinkArgs.builder()
            .contentVersion(contentVersion?.applyValue({ args0 -> args0 }))
            .uri(uri.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DeploymentStacksParametersLinkArgs].
 */
@PulumiTagMarker
public class DeploymentStacksParametersLinkArgsBuilder internal constructor() {
    private var contentVersion: Output<String>? = null

    private var uri: Output<String>? = null

    /**
     * @param value If included, must match the ContentVersion in the template.
     */
    @JvmName("lsmoabjppklsliub")
    public suspend fun contentVersion(`value`: Output<String>) {
        this.contentVersion = value
    }

    /**
     * @param value The URI of the parameters file.
     */
    @JvmName("pltsqstwxduuekqe")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value If included, must match the ContentVersion in the template.
     */
    @JvmName("gcsxjltwbdjrqkvl")
    public suspend fun contentVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentVersion = mapped
    }

    /**
     * @param value The URI of the parameters file.
     */
    @JvmName("mhfhrdfhonxdsiyl")
    public suspend fun uri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): DeploymentStacksParametersLinkArgs = DeploymentStacksParametersLinkArgs(
        contentVersion = contentVersion,
        uri = uri ?: throw PulumiNullFieldException("uri"),
    )
}
